#
# spec file for package revelation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           revelation
Version:        0.5.5
Release:        1.3
Summary:        Password manager for GNOME
License:        GPL-2.0-only
Group:          Productivity/Security
URL:            http://revelation.olasagasti.info
Source:         https://github.com/mikelolasagasti/revelation/releases/download/revelation-%{version}/revelation-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  intltool >= 0.35.0
BuildRequires:  meson
BuildRequires:  perl-XML-Parser
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-pwquality
BuildRequires:  python3-pycryptodomex
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-pwquality
Requires:       python3-pycryptodomex
BuildArch:      noarch

%description
Revelation is a password manager. It organizes accounts in
a tree structure, and stores them as AES-encrypted XML files.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes %{buildroot}%{_prefix}

%files
%defattr(-, root, root)
%license COPYING
%doc AUTHORS ChangeLog README.md TODO NEWS
%{_bindir}/revelation
%{_datadir}/applications/info.olasagasti.revelation.desktop
%{_datadir}/metainfo/info.olasagasti.revelation.metainfo.xml
%{_datadir}/revelation/
%{_datadir}/icons/hicolor/*/apps/info.olasagasti.revelation*
%{_datadir}/mime/packages/revelation.xml
%{python3_sitelib}/revelation/
%{_datadir}/glib-2.0/schemas/info.olasagasti.revelation.gschema.xml
%{_datadir}/icons/hicolor/48x48/mimetypes/gnome-mime-application-x-revelation.png

%files lang -f %{name}.lang

%changelog
* Wed Jul 17 2024 ming li <mli@suse.com>
- Update to version 0.5.5:
  * Bugfixes:
  - Fix building with >=Meson-0.60
  - Fix importing GPass-0.5.1 files
  - Fix Metainfo errors reported by Debian
  * Others:
  - Code changes based on flake8 and bandit
  - First Meson only supported release
  * Updated translations.
- Remove revelation-mesonfix-061.patch, the new version has fixed
  this issue
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add revelation-mesonfix-061.patch: Fix build with meson 0.61 and
  newer.
* Tue Jun 22 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.5.4:
  + Keyboard Shortcuts Page (KSP) available.
  + Port to Meson build system.
  + Migrate from Gtk.FileChooserDialog to Gtk.FileChooserNative to
    avoid having to grant full $HOME access in Flatpak.
  + KeepassXC CSV importer.
- Port to meson build system:
  + Add meson BuildRequires.
  + Drop automake and autoconf BuildRequires.
  + Replace configure/make/make_install macros with
    meson/meson_build/meson_install.
- Add gobject-introspection BuildRequires: new dependency.
- Drop desktop.patch (included upstream)
* Sun Sep 27 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.5.3
- Add desktop.patch to upstream changes
* Fri Sep  4 2020 Matthias Mailänder <mailaender@opensuse.org>
- Drop appdata.patch and file-open.patch
- Update to version 0.5.2
* Mon Oct  3 2016 mailaender@opensuse.org
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
- Add file-open.patch to resolve automatic DB opening issues.
* Mon May  2 2016 mailaender@opensuse.org
- Add missing runtime dependency python-gconf (fixes boo#972104).
* Wed Feb 17 2016 dimstar@opensuse.org
- .spec file cleanup / reorganisation.
* Tue Feb  2 2016 mailaender@opensuse.org
- Add missing dependency python-cracklib
* Thu Aug 23 2012 mailaender@opensuse.org
- Update to 0.4.14
* Sat Dec 24 2011 mailaender@opensuse.org
- Update to 0.4.12
* Tue Mar  6 2007 wberrier@novell.com
- Update to 0.4.11
- Adapt for suse and buildservice (fix dep names, add additional files,
  fix desktop file)
